@@ -4,6 +4,7 @@ Syntax tests for the lark based HGVS parser - taken from the HGVS website.
 
 import pytest
 
+from mutalyzer_hgvs_parser.exceptions import UnexpectedCharacter, UnexpectedEnd
 from mutalyzer_hgvs_parser.hgvs_parser import HgvsParser
 
 
@@ -156,6 +157,18 @@ def parser():
         # White spaces
         " NC_000023.10 : g . 33038255 C > A ",
         "LRG_199 t1 :c.( 4071+1_4072 -1)_ ( 5154 +1_5155-1)[ 3]",
+        # pter and qter
+        "NC_000002.12:g.pterdel",
+        "NC_000002.12:g.qterdel",
+        "NC_000002.12:g.pter_qterdel",
+        "NC_000002.12:g.pter_100del",
+        "NC_000002.12:g.100_qterdel",
+        "NC_000002.12:g.pter_8247756delinspter_qter",
+        "NC_000002.12:g.pter_8247756delins[NC_000011.10:g.pter_15825272]",
+        "NC_000002.12:g.1_qterdelins[NC_000011.10:g.pter_qter]",
+        "NC_000002.12:g.pter_qterdelins[NC_000011.10:g.pter_qter]",
+        "NC_000002.12:g.pterdelins[NC_000011.10:g.pter_qter]",
+        "NC_000002.12:g.qterdelins[NC_000011.10:g.pter_qter]",
     ],
 )
 def test_correct_syntax(parser, description):
@@ -239,3 +252,40 @@ def test_incorrect_syntax(parser, description):
     """
     with pytest.raises(Exception):
         HgvsParser().parse(description)
+
+
+def test_unexpected_end():
+    try:
+        HgvsParser().parse("REF:g.1de")
+    except UnexpectedEnd as e:
+        s = e.serialize()
+        assert s["pos_in_stream"] == 8
+        assert s["unexpected_character"] == "e"
+        assert s["description"] == "REF:g.1de"
+        assert set(s["expecting"]) == {
+            "a reference / selector ID",
+            "':' between the reference part and the coordinate system",
+            "'(' for an uncertainty start or before a selector ID",
+        }
+
+
+def test_unexpected_character():
+    try:
+        HgvsParser().parse("REF_1:g.pter_100delins[REF_2:g.]")
+    except UnexpectedCharacter as e:
+        s = e.serialize()
+        assert s["pos_in_stream"] == 31
+        assert s["unexpected_character"] == "]"
+        assert s["description"] == "REF_1:g.pter_100delins[REF_2:g.]"
+        assert set(s["expecting"]) == {
+            "'=' to indicate no changes",
+            "a number (to indicate a location or a length)",
+            "'(['",
+            "?",
+            "'[('",
+            "'[' for multiple variants, insertions, or repeats",
+            "'(' for an uncertainty start or before a selector ID",
+            "'*' or '-' for an outside CDS location",
+            "'pter' or 'qter'",
+            "'(=)' for predicted no changes",
+        }
